/*
 * Copyright (C) 2015 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef GAPIC_ID_H
#define GAPIC_ID_H

#include <functional>
#include <stdint.h>

namespace gapic {

// Id is a 20-byte unique identifier.
struct Id {
    // Construct an Id with the hash of the given memory address.
    static Id Hash(const void* ptr, uint64_t size);

    bool operator == (const Id& rhs) const;

    uint8_t data[20];
};

} // namespace gapic

namespace std {
template <> struct hash<gapic::Id> {
    inline size_t operator()(const gapic::Id& id) const {
        return *reinterpret_cast<const size_t*>(id.data);
    }
};

}  // namespace gapic

#endif // GAPIC_ID_H
