// Copyright (C) 2015 The Android Open Source Project
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//      http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package protocol

import (
	"android.googlesource.com/platform/tools/gpu/binary"
)

// ResourceInfo describes a resource used by a Payload.
type ResourceInfo struct {
	binary.Generate
	ID   string // The resource identifier as a string.
	Size uint32 // The size in bytes of the resource.
}

// Payload contains all the information to perform a replay. The encoded form
// is what is passed to the replay system.
type Payload struct {
	binary.Generate
	StackSize          uint32         // Maximum number of values.
	VolatileMemorySize uint32         // In bytes.
	Constants          []byte         // The constant buffer.
	Resources          []ResourceInfo // Resources used by this replay payload.
	Opcodes            []byte         // The encoded list of opcodes.
}
